/*********************************************************************

 Author        : ADI - Apps            www.analog.com/MicroConverter

 Date          : May. 2006

 File          : main.c, SPI_Functions.c, SPI_Functions.h

 Hardware      : ADuC702x Rev I silicon, Spansion S25FL032A
                  ADuC702x        ->      S25FL032A
                  P1.4  ( SCLK )          SCK   ( Pin 16 )
                  P1.5  ( MISO )          SO    ( Pin 8 )
                  P1.6  ( MOSI )          SI    ( Pin 15 )
                  P1.7  ( CS )            CS#   ( Pin 7 )
                  P3.0                    W#    ( Pin 9 )
                  P3.1                    Hold# ( Pin 1 )

 Description   : Example program for integration of Spansion S25FL032A
                 SPI Flash Module.

                 The Flash is firstly erased, and then four pages of data is
                 written too it.

*********************************************************************/

/* Place Include files here */

#include "ioADuC7026.h"
#include "SPI_Functions.h"

// Place Function Prototypes here

void Init_ADuC7024(void);

// Place Global Variables here

#define DATA_TOTAL 256
#define Sector_Erase_Enable

// Main Function

int main()
{
// Place local variable definitions here

  volatile unsigned long SPI_Slave_ID;
  unsigned char c_data_in[DATA_TOTAL],c_data_out[DATA_TOTAL];
  int i;

  Init_ADuC7024();  // Configure GPIO, SPI and CD Divider

  
  GP1DAT    =   0xF0000000; // Drive CS low
  SPITX = 0x9F;             // Transmit command to read the ID, generate 8 SPI clock
  while((SPISTA&0x1) == 1 ) // Wait until command is transmitted
  {}  
  GP1DAT    =   0xF0F00000; // Drive CS high  
  while((SPISTA&0x8) == 0 ) // Wait until RX register is full
  {}
   while ( ( SPISTA & 0x8 ) == 0x8 )
  {
     i = SPIRX;
  } 
  
  //  Setup Dummy data to write
  for ( i = 0; i < DATA_TOTAL  ; i++)
  {
    c_data_in[i] = i;
  }

  //  Read The Identification of the device
  SPI_Slave_ID = Read_Identification();
  //  Write to Status register to ensure that no protection is enabled
  Write_Status_Register(0x0);

#ifdef  Sector_Erase_Enable
  //  Erase sector used only
  Sector_Erase(0);
#else
  //  Erase entire chip
  Bulk_Erase();
#endif

  //  read data from Flash/EE
  Data_Read(0x0300, c_data_out  , DATA_TOTAL );

  // Write Data to four pages of the first sector
  Page_Program(0x00, c_data_in, DATA_TOTAL);
  Page_Program(0x0100, c_data_in, DATA_TOTAL);
  Page_Program(0x0200, c_data_in, DATA_TOTAL);
  Page_Program(0x0300, c_data_in, DATA_TOTAL);

  //  Read Data from fourth page of first sector
  for ( i = 0 ; i < 100000 ; i++ )
  {
    Data_Read(0x0310, c_data_out  , 1 );
    if ( c_data_out[0] != 0x10)
    {
      while(1)
      {}
    }
  }

while(1)
  {
    
  }
}

// Configure PLL Divider, GPIO and SPI for 3.482 MHz Operation

void Init_ADuC7024(void)
{
    POWKEY1   =   0x1;
    POWCON    =   0x00;   //  Configure Core operation for CD = 0
    POWKEY2   =   0xf4;

                          // Enable SPI Pins for MASTER Mode. Control SS manually
    GP1CON    =   0x02220000;
                          // P3.0 is Write protect pin W#
                          // P3.1 is Hold pin. This are driven high for this program
    GP3DAT    =   0x03030000;
    SPIDIV    =   0x05;   // Configure SPI for 3.482MHz operation
    SPICON    =   0x104F; // Enable SPI master in continuous transfer mode
			  // slave select will stay low during the all transmission
}
